@@ -5,6 +5,18 @@
 #' @include head_bucket.R
 NULL
 
+VERSION_ID_SUFFIX <- "?versionId="
+ACCESSPOINT_ARN <- paste0(
+  "^arn:(aws).*:(s3|s3-object-lambda):[a-z\\-0-9]*:[0-9]{12}:accesspoint[/:]",
+  "[a-zA-Z0-9\\-.]{1,63}$"
+)
+OUTPOST_ARN <- paste0(
+  "^arn:(aws).*:s3-outposts:[a-z\\-0-9]+:[0-9]{12}:outpost[/:]",
+  "[a-zA-Z0-9\\-]{1,63}[/:]accesspoint[/:][a-zA-Z0-9\\-]{1,63}$"
+)
+
+VALID_S3_ARN <- paste(ACCESSPOINT_ARN, OUTPOST_ARN, sep = "|")
+
 ################################################################################
 
 convert_file_to_raw <- function(request) {
@@ -470,6 +482,48 @@ set_request_url <- function(original_endpoint,
   return(final_endpoint)
 }
 
+################################################################################
+handle_copy_source_param <- function(request) {
+  if (!(request$operation$name %in% c("CopyObject", "CopyPart"))) {
+    return(request)
+  }
+  source <- request$params$CopySource
+  if (is.character(source)) {
+    request$params$CopySource <- quote_source_header(source)
+  } else if (is.list(source)) {
+    request$params$CopySource <- quote_source_header_from_list(source)
+  }
+  return(request)
+}
+
+quote_source_header <- function(source) {
+  result <- strsplit(source, VERSION_ID_SUFFIX, fixed = T)[[1]]
+  if (is.na(result[2])) {
+    return(paws_url_encoder(result[1], "/"))
+  } else {
+    return(paste0(paws_url_encoder(result[1], "/"), VERSION_ID_SUFFIX, result[2]))
+  }
+}
+
+quote_source_header_from_list <- function(source) {
+  if (is.null(bucket <- source[["Bucket"]])) {
+    stopf("CopySource list is missing required parameter: Bucket")
+  }
+  if (is.null(key <- source[["Key"]])) {
+    stopf("CopySource list is missing required parameter: Key")
+  }
+  if (grepl(VALID_S3_ARN, bucket, perl = T)) {
+    final <- sprintf("%s/object/%s", bucket, key)
+  } else {
+    final <- sprintf("%s/%s", bucket, key)
+  }
+  final <- paws_url_encoder(final, "/")
+  if (!is.null(version_id <- source[["VersionId"]])) {
+    final <- paste0(final, VERSION_ID_SUFFIX, version_id)
+  }
+  return(final)
+}
+
 ################################################################################
 
 customizations$s3 <- function(handlers) {
@@ -485,6 +539,10 @@ customizations$s3 <- function(handlers) {
     handlers$build,
     convert_file_to_raw
   )
+  handlers$build <- handlers_add_front(
+    handlers$build,
+    handle_copy_source_param
+  )
   handlers$build <- handlers_add_front(
     handlers$build,
     sse_md5_build
